@@ -67,6 +67,9 @@
 #include <QRegularExpression>
 #include <QtWebEngineWidgetsVersion>
 #include <QtWebEngineCoreVersion>
+#include <QtGuiVersion>
+#include <QStyleHints>
+#include <QNetworkInformation>
 
 #include <QWebEngineNotification>
 #include <QWebEngineUrlScheme>
@@ -149,11 +152,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     }
 #endif
 
-    QByteArray chromium_flags = qgetenv("QTWEBENGINE_CHROMIUM_FLAGS");
-    chromium_flags.append(" --enable-features=WebRTCPipeWireCapturer");
-    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromium_flags);
-
-    QUrl startUrl;
+    QList<QUrl> startUrls;
     QString startProfile;
     QStringList messages;
 
@@ -196,15 +195,15 @@ MainApplication::MainApplication(int &argc, char** argv)
                 newInstance = true;
                 break;
             case Qz::CL_OpenUrlInCurrentTab:
-                startUrl = QUrl::fromUserInput(pair.text);
+                startUrls.append(QUrl::fromUserInput(pair.text));
                 messages.append(QSL("ACTION:OpenUrlInCurrentTab") + pair.text);
                 break;
             case Qz::CL_OpenUrlInNewWindow:
-                startUrl = QUrl::fromUserInput(pair.text);
+                startUrls.append(QUrl::fromUserInput(pair.text));
                 messages.append(QSL("ACTION:OpenUrlInNewWindow") + pair.text);
                 break;
             case Qz::CL_OpenUrl:
-                startUrl = QUrl::fromUserInput(pair.text);
+                startUrls.append(QUrl::fromUserInput(pair.text));
                 messages.append(QSL("URL:") + pair.text);
                 break;
             case Qz::CL_ExitAction:
@@ -287,11 +286,8 @@ MainApplication::MainApplication(int &argc, char** argv)
     profileManager.initCurrentProfile(startProfile);
 
     Settings::createSettings(DataPaths::currentProfilePath() + QLatin1String("/settings.ini"));
-    if (Settings::globalSettings()->value("Web-Browser-Settings/hardwareAccel", false).toBool()) {
-	    chromium_flags.append(" --enable-oop-rasterization --enable-gpu-rasterization --enable-native-gpu-memory-buffers --use-gl=desktop");
-	    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromium_flags);
-    }
 
+    setChromiumFlags();
     NetworkManager::registerSchemes();
     registerAllowedSchemes();
 
@@ -312,6 +308,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     m_networkManager = new NetworkManager(this);
 
+    initNetworkInformation();
     setupUserScripts();
 
     if (!isPrivate() && !isTestModeEnabled()) {
@@ -350,7 +347,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     if (!noAddons)
         m_plugins->loadPlugins();
 
-    BrowserWindow* window = createWindow(Qz::BW_FirstAppWindow, startUrl);
+    BrowserWindow *window = createWindow(Qz::BW_FirstAppWindow, std::move(startUrls));
     connect(window, SIGNAL(startingCompleted()), this, SLOT(restoreOverrideCursor()));
 
     connect(this, &QApplication::focusChanged, this, &MainApplication::onFocusChanged);
@@ -412,6 +409,40 @@ MainApplication::~MainApplication()
     Settings::syncSettings();
 }
 
+void MainApplication::setChromiumFlags()
+{
+    QByteArray chromium_flags = qgetenv("QTWEBENGINE_CHROMIUM_FLAGS");
+    chromium_flags.append(" --enable-features=WebRTCPipeWireCapturer");
+
+    if (Settings::globalSettings()->value("Web-Browser-Settings/hardwareAccel", false).toBool()) {
+        chromium_flags.append(" --enable-oop-rasterization --enable-gpu-rasterization --enable-native-gpu-memory-buffers");
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+        chromium_flags.append(" --use-gl=angle");
+#else
+        chromium_flags.append(" --use-gl=desktop");
+#endif
+        qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromium_flags);
+    }
+
+    int prefferColorScheme = Settings::globalSettings()->value("Web-Browser-Settings/prefferColorScheme", Qz::ColorScheme_Auto).toInt();
+    if (   (prefferColorScheme == Qz::ColorScheme_Dark)
+#if QTGUI_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+        || ((prefferColorScheme == Qz::ColorScheme_Auto) && (styleHints()->colorScheme() == Qt::ColorScheme::Dark))
+#endif
+    ) {
+        chromium_flags.append(" --blink-settings=preferredColorScheme=0");
+    }
+    else if ((prefferColorScheme == Qz::ColorScheme_Light)
+#if QTGUI_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+        || ((prefferColorScheme == Qz::ColorScheme_Auto) && (styleHints()->colorScheme() == Qt::ColorScheme::Light))
+#endif
+    ) {
+        chromium_flags.append(" --blink-settings=preferredColorScheme=1");
+    }
+
+    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromium_flags);
+}
+
 bool MainApplication::isClosing() const
 {
     return m_isClosing;
@@ -456,12 +487,17 @@ BrowserWindow* MainApplication::getWindow() const
 }
 
 BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const QUrl &startUrl)
+{
+    return createWindow(type, QList<QUrl>({startUrl}));
+}
+
+BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const QList<QUrl> &startUrls)
 {
     if (windowCount() == 0 && type != Qz::BW_MacFirstWindow) {
         type = Qz::BW_FirstAppWindow;
     }
 
-    auto* window = new BrowserWindow(type, startUrl);
+    auto *window = new BrowserWindow(type, startUrls);
     connect(window, &QObject::destroyed, this, &MainApplication::windowDestroyed);
 
     m_windows.prepend(window);
@@ -974,7 +1010,6 @@ void MainApplication::loadSettings()
     webSettings->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, settings.value(QSL("allowJavaScriptOpenWindow"), false).toBool());
     webSettings->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, settings.value(QSL("allowJavaScriptAccessClipboard"), true).toBool());
     webSettings->setAttribute(QWebEngineSettings::LinksIncludedInFocusChain, settings.value(QSL("IncludeLinkInFocusChain"), false).toBool());
-    webSettings->setAttribute(QWebEngineSettings::XSSAuditingEnabled, settings.value(QSL("XSSAuditing"), false).toBool());
     webSettings->setAttribute(QWebEngineSettings::PrintElementBackgrounds, settings.value(QSL("PrintElementBackground"), true).toBool());
     webSettings->setAttribute(QWebEngineSettings::SpatialNavigationEnabled, settings.value(QSL("SpatialNavigation"), false).toBool());
     webSettings->setAttribute(QWebEngineSettings::ScrollAnimatorEnabled, settings.value(QSL("AnimateScrolling"), true).toBool());
@@ -1157,6 +1192,15 @@ void MainApplication::registerAllowedSchemes()
     }
 }
 
+void MainApplication::initNetworkInformation()
+{
+    bool loaded = QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability |
+                                                             QNetworkInformation::Feature::CaptivePortal);
+    if (!loaded) {
+        QNetworkInformation::loadDefaultBackend();
+    }
+}
+
 void MainApplication::setupUserScripts()
 {
     // WebChannel for SafeJsWorld
